window.Gleam.initSearch([{"doc":"sketch_css","title":"sketch_css","content":"# Sketch CSS\n\n&gt; In case you&#39;re here and don&#39;t know Sketch, take a look at\n&gt; [`sketch` package](https://hexdocs.pm/sketch)!\n\n&gt; This readme is a carbon-copy of the Sketch CSS section in `sketch` readme.\n\nSketch CSS is a tool to generate CSS from Sketch Class definitions. Because pure\nCSS generation is straightforward, `sketch_css` does not need a cache to\ngenerate correct CSS files. Instead, `sketch_css` ships with a CLI tool, able to\nread your Gleam styles files, and output corresponding your CSS automagically,\nwhile providing an abstraction layer written in Gleam, to make sure you&#39;re using\nthe right classes! It&#39;s an other way to leverage on Sketch core and enjoy the\nstyling in Gleam, while taking advantage of all the static CSS power!\n\nTo run the generator, you have to use the command\n`gleam run -m sketch/css generate` at the root of your project. By default,\n`sketch_css` will try to read all files named `*_styles.gleam`, `*_css.gleam`\nand `*_sketch.gleam` in your `src` folder, no matter where they are. You can put\nthem at root, nested, or in a folder called `css`, `sketch_css` does not care!\nAfter fetching the styles files, `sketch_css` will output your generated CSS\nfiles in a `styles` folder, at the root of the project. They can then be served\nin the way you want. In the same time, `sketch_css` will output Gleam interfaces\nin `src/sketch/styles`, matching your styles files, to use in your project!\n\n### Options\n\nSketch CSS generation has strong defaults, but everything can be customised. Use\nthe CLI flags to configure what you need. CLI exposes 3 flags:\n\n- `--dest`, accepting a folder, relative to current directory. It defaults to\n  `styles`\n- `--src`, accepting a folder, relative to current directory. It defaults to\n  `src`.\n- `--interface`, accepting a folder, relative to current directory. It defaults\n  to `src/sketch/styles`.\n\n### A note on generation algorithm\n\nBecause a Sketch `Class` can be generated in multiple ways, and with variable,\nSketch CSS takes that into account. Every simple Sketch `Class` will be iso\ngenerated in CSS, but every Sketch `Class` that contains variable will be\ngenerated with the variable taken into account! Sketch CSS being opinionated, it\ngenerates the class, with a CSS variable, letting you update it, override it,\netc.\n\nAll `_` are also automatically transformed into `-`, because CSS classes are\nmost of the time used with dashes, so Sketch CSS follows that convention!\n\n### Example\n\n```gleam\n// src/main_styles.gleam\nimport sketch\n\nfn flexer() {\n  sketch.class([\n    sketch.display(&quot;flex&quot;),\n  ])\n}\n\nfn flexer_direction(flex_direction: String) {\n  sketch.class([\n    sketch.compose(flexer()),\n    sketch.flex_direction(flex_direction),\n  ])\n}\n```\n\n```css\n/* styles/main_styles.css */\n.flexer {\n  display: flex;\n}\n\n.flexer-direction {\n  flex-direction: var(--flex-direction);\n}\n```\n\n```gleam\n// src/sketch/styles/main_styles.gleam\npub const flexer = &quot;flexer&quot;\n\npub const flexer_direction = &quot;flexer flexer-direction&quot;\n```\n","url":"index.html"},{"doc":"sketch/css/error","title":"Error","content":"pub type Error {\n  ApplicationError(message: String)\n  SimplifileError(error: simplifile.FileError)\n  GlanceError(error: glance.Error)\n}\n\nApplicationError(message: String)\n\n\nSimplifileError(error: simplifile.FileError)\n\n\nGlanceError(error: glance.Error)\n\n\nSynonyms:\nsketch/css/error.Error\nsketch/css/error Error","url":"sketch/css/error.html#Error"},{"doc":"sketch/css/error","title":"glance","content":"pub fn glance(\n  err: Result(a, Error),\n) -&gt; Result(a, sketch/css/error.Error)\n\nSynonyms:\nsketch/css/error.glance\nsketch/css/error glance","url":"sketch/css/error.html#glance"},{"doc":"sketch/css/error","title":"not_a_directory","content":"pub fn not_a_directory(dir: String) -&gt; Result(a, Error)\n\nSynonyms:\nsketch/css/error.not_a_directory\nsketch/css/error not_a_directory","url":"sketch/css/error.html#not_a_directory"},{"doc":"sketch/css/error","title":"simplifile","content":"pub fn simplifile(err: Result(a, FileError)) -&gt; Result(a, Error)\n\nSynonyms:\nsketch/css/error.simplifile\nsketch/css/error simplifile","url":"sketch/css/error.html#simplifile"},{"doc":"sketch/css/error","title":"sketch/css/error","content":"","url":"sketch/css/error.html"},{"doc":"sketch/css","title":"Css","content":"pub type Css {\n  Css(classes: List(#(String, String)), content: List(String))\n}\n Definition of a StyleSheet. `classes` ensures a mapping between functions\n and class names. `content` is the corresponding CSS classes.\nCss(classes: List(#(String, String)), content: List(String))\n\n\nSynonyms:\nsketch/css.Css\nsketch/css Css","url":"sketch/css.html#Css"},{"doc":"sketch/css","title":"Module","content":"pub type Module {\n  Module(\n    path: String,\n    content: String,\n    ast: Option(glance.Module),\n  )\n}\n Definition of a Gleam styles definitions file. `path` is up to you, to\n retrieve your module easily. `content` should be a valid Gleam source file.\nModule(path: String, content: String, ast: Option(glance.Module))\n\n\nSynonyms:\nsketch/css.Module\nsketch/css Module","url":"sketch/css.html#Module"},{"doc":"sketch/css","title":"compute_modules","content":"pub fn compute_modules(\n  modules: List(Module),\n) -&gt; List(#(Module, Css))\n Compute the content of a bunch of Gleam Styles modules.\n This function is designed to be used outside of the CLI, if you need it in\n your frontend for example.\nSynonyms:\nsketch/css.compute_modules\nsketch/css compute_modules","url":"sketch/css.html#compute_modules"},{"doc":"sketch/css","title":"generate_stylesheets","content":"pub fn generate_stylesheets(\n  src src: String,\n  dst dst: String,\n  interface src_interfaces: String,\n) -&gt; Result(Nil, Error)\n Generate stylesheets from Gleam style definitions files. Recursively extract\n all files ending with `_styles.gleam`, `_css.gleam` or `_sketch.gleam` to\n proper stylesheets, and output some files interfaces to interact with them.\n\n `src` should be a relative path containing the source files.\n `dst` should be a relative path where to output CSS files.\n `interface` should be a relative path where to output Gleam files.\nSynonyms:\nsketch/css.generate_stylesheets\nsketch/css generate_stylesheets","url":"sketch/css.html#generate_stylesheets"},{"doc":"sketch/css","title":"main","content":"pub fn main() -&gt; Nil\n The `main` function is used as an entrypoint for Sketch CSS. That function\n not meant to be used in your code, but is called when you use `gleam run`\n from the command line.\n\n \n gleam run -m sketch/css\n \nSynonyms:\nsketch/css.main\nsketch/css main","url":"sketch/css.html#main"},{"doc":"sketch/css","title":"sketch/css","content":"","url":"sketch/css.html"}]);